@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: downloader-view.c,v 1.50 2004/01/29 11:42:33 chpe Exp $
+ *  $Id: downloader-view.c,v 1.56 2004/02/15 11:03:30 marco Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -156,14 +156,7 @@ downloader_view_class_init (DownloaderViewClass *klass)
 static void
 status_icon_activated (EggStatusIcon *icon, DownloaderView *dv)
 {
-	if (GTK_WIDGET_VISIBLE (dv->priv->window))
-	{
-		gtk_widget_hide (dv->priv->window);
-	}
-	else
-	{
-		gtk_window_present (GTK_WINDOW (dv->priv->window));
-	}
+	gtk_window_present (GTK_WINDOW (dv->priv->window));
 }
 
 static void
@@ -212,6 +205,8 @@ downloader_view_new (void)
 {
 	return EPHY_DOWNLOADER_VIEW (g_object_new (EPHY_TYPE_DOWNLOADER_VIEW,
 			 			   "persist-position", TRUE,
+						   "default-width", 420,
+						   "default-height", 250,
 			 			   NULL));
 }
 
@@ -241,6 +236,50 @@ get_row_from_download (DownloaderView *dv, EphyDownload *download)
 	return  g_hash_table_lookup (dv->priv->downloads_hash, download);
 }
 
+static void
+update_buttons (DownloaderView *dv)
+{
+	GtkTreeSelection *selection;
+	GtkTreeModel *model;
+	GtkTreeIter iter;
+	GValue val = {0, };
+	EphyDownload *download;
+	EphyDownloadState state;
+	gboolean pause_enabled = FALSE;
+	gboolean abort_enabled = FALSE;
+	gboolean label_pause = TRUE;
+
+	selection = gtk_tree_view_get_selection (GTK_TREE_VIEW(dv->priv->treeview));
+
+	if (gtk_tree_selection_get_selected (selection, &model, &iter))
+	{
+		gtk_tree_model_get_value (model, &iter, COL_DOWNLOAD_OBJECT, &val);
+		download = g_value_get_object (&val);
+		g_value_unset (&val);
+
+		state = ephy_download_get_state (download);
+
+		switch (state)
+		{
+		case EPHY_DOWNLOAD_DOWNLOADING:
+			pause_enabled = TRUE;
+			abort_enabled = TRUE;
+			break;
+		case EPHY_DOWNLOAD_PAUSED:
+			pause_enabled = TRUE;
+			abort_enabled = TRUE;
+			label_pause = FALSE;
+			break;
+		default:
+			abort_enabled = TRUE;
+			break;
+		}
+	}
+	gtk_widget_set_sensitive (dv->priv->pause_button, pause_enabled);
+	gtk_widget_set_sensitive (dv->priv->abort_button, abort_enabled);
+	gtk_button_set_label (GTK_BUTTON (dv->priv->pause_button), label_pause ? _("_Pause") : _("_Resume"));
+}
+
 static void
 update_download_row (DownloaderView *dv, EphyDownload *download)
 {
@@ -322,6 +361,8 @@ update_download_row (DownloaderView *dv, EphyDownload *download)
 	g_free (cur_progress);
 	g_free (file);
 	g_free (remaining);
+
+	update_buttons (dv);
 }
 
 static void
@@ -423,6 +464,12 @@ downloader_view_add_download (DownloaderView *dv,
 	ephy_dialog_show (EPHY_DIALOG (dv));
 }
 
+static void
+selection_changed (GtkTreeSelection *selection, DownloaderView *dv)
+{
+	update_buttons (dv);
+}
+
 static void
 downloader_view_build_ui (DownloaderView *dv)
 {
@@ -430,9 +477,9 @@ downloader_view_build_ui (DownloaderView *dv)
 	GtkListStore *liststore;
 	GtkTreeViewColumn *column;
 	GtkCellRenderer *renderer;
-	GtkTreeSelection *selection;
 	GdkPixbuf *icon;
 	EphyDialog *d = EPHY_DIALOG (dv);
+	GtkTreeSelection *selection;
 
 	ephy_dialog_construct (d,
                                properties,
@@ -447,7 +494,7 @@ downloader_view_build_ui (DownloaderView *dv)
 	priv->abort_button = ephy_dialog_get_control (d, properties[PROP_ABORT_BUTTON].id);
 
 	gtk_tree_selection_set_mode (gtk_tree_view_get_selection (GTK_TREE_VIEW (priv->treeview)),
-				     GTK_SELECTION_SINGLE);
+				     GTK_SELECTION_BROWSE);
 
 	liststore = gtk_list_store_new (4,
 					G_TYPE_INT,
@@ -469,6 +516,7 @@ downloader_view_build_ui (DownloaderView *dv)
 						     NULL);
 	column = gtk_tree_view_get_column (GTK_TREE_VIEW(priv->treeview), 0);
         gtk_tree_view_column_set_reorderable (column, TRUE);
+	gtk_tree_view_column_set_resizable (column, TRUE);
         gtk_tree_view_column_set_sort_column_id (column, COL_PERCENT);
 
 	renderer = gtk_cell_renderer_text_new ();
@@ -481,6 +529,7 @@ downloader_view_build_ui (DownloaderView *dv)
 					   COL_FILE);
         gtk_tree_view_column_set_expand (column, TRUE);
         gtk_tree_view_column_set_reorderable (column, TRUE);
+	gtk_tree_view_column_set_resizable (column, TRUE);
         gtk_tree_view_column_set_sort_column_id (column, COL_FILE);
 
 	renderer = gtk_cell_renderer_text_new ();
@@ -493,11 +542,9 @@ downloader_view_build_ui (DownloaderView *dv)
 	column = gtk_tree_view_get_column (GTK_TREE_VIEW(priv->treeview),
 					   COL_REMAINING);
         gtk_tree_view_column_set_reorderable (column, TRUE);
+	gtk_tree_view_column_set_resizable (column, TRUE);
         gtk_tree_view_column_set_sort_column_id (column, COL_REMAINING);
 
-	selection = gtk_tree_view_get_selection (GTK_TREE_VIEW(priv->treeview));
-	gtk_tree_selection_set_mode (selection, GTK_SELECTION_SINGLE);
-
 	priv->model = GTK_TREE_MODEL (liststore);
 
 	icon = gtk_widget_render_icon (GTK_WIDGET (priv->window),
@@ -505,6 +552,9 @@ downloader_view_build_ui (DownloaderView *dv)
 				       GTK_ICON_SIZE_MENU,
 				       NULL);
 	gtk_window_set_icon (GTK_WINDOW(priv->window), icon);
+
+	selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (priv->treeview));
+	g_signal_connect (selection, "changed", G_CALLBACK (selection_changed), dv);
 }
 
 void
@@ -530,13 +580,12 @@ download_dialog_pause_cb (GtkButton *button, DownloaderView *dv)
 	if (state == EPHY_DOWNLOAD_DOWNLOADING)
 	{
 		ephy_download_pause (download);
-		gtk_button_set_label (GTK_BUTTON (dv->priv->pause_button), _("_Resume"));
 	}
 	else if (state == EPHY_DOWNLOAD_PAUSED)
 	{
 		ephy_download_resume (download);
-		gtk_button_set_label (GTK_BUTTON (dv->priv->pause_button), _("_Pause"));
 	}
+	update_buttons (dv);
 }
 
 void
@@ -613,7 +662,8 @@ download_dialog_abort_cb (GtkButton *button, DownloaderView *dv)
 
 	selection = gtk_tree_view_get_selection (GTK_TREE_VIEW(dv->priv->treeview));
 	
-	gtk_tree_selection_get_selected (selection, &model, &iter);
+	if (!gtk_tree_selection_get_selected (selection, &model, &iter)) return;
+
 	gtk_tree_model_get_value (model, &iter, COL_DOWNLOAD_OBJECT, &val);
 	
 	download = g_value_get_object (&val);
