@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-embed-single.h,v 1.16 2003/11/21 23:03:31 chpe Exp $
+ *  $Id: ephy-embed-single.h,v 1.19 2004/02/20 11:49:42 chpe Exp $
  */
 
 #ifndef EPHY_EMBED_SINGLE_H
@@ -28,15 +28,15 @@ G_BEGIN_DECLS
 
 #define EPHY_TYPE_EMBED_SINGLE		(ephy_embed_single_get_type ())
 #define EPHY_EMBED_SINGLE(o)		(G_TYPE_CHECK_INSTANCE_CAST ((o), EPHY_TYPE_EMBED_SINGLE, EphyEmbedSingle))
-#define EPHY_EMBED_SINGLE_CLASS(k)	(G_TYPE_CHECK_CLASS_CAST((k), EPHY_TYPE_EMBED_SINGLE, EphyEmbedSingleClass))
+#define EPHY_EMBED_SINGLE_IFACE(k)	(G_TYPE_CHECK_CLASS_CAST((k), EPHY_TYPE_EMBED_SINGLE, EphyEmbedSingleIface))
 #define EPHY_IS_EMBED_SINGLE(o)		(G_TYPE_CHECK_INSTANCE_TYPE ((o), EPHY_TYPE_EMBED_SINGLE))
-#define EPHY_IS_EMBED_SINGLE_CLASS(k)	(G_TYPE_CHECK_CLASS_TYPE ((k), EPHY_TYPE_EMBED_SINGLE))
-#define EPHY_EMBED_SINGLE_GET_CLASS(i)	(G_TYPE_INSTANCE_GET_INTERFACE ((i), EPHY_TYPE_EMBED_SINGLE, EphyEmbedSingleClass))
+#define EPHY_IS_EMBED_SINGLE_IFACE(k)	(G_TYPE_CHECK_CLASS_TYPE ((k), EPHY_TYPE_EMBED_SINGLE))
+#define EPHY_EMBED_SINGLE_GET_IFACE(i)	(G_TYPE_INSTANCE_GET_INTERFACE ((i), EPHY_TYPE_EMBED_SINGLE, EphyEmbedSingleIface))
 
-typedef struct EphyEmbedSingleClass	EphyEmbedSingleClass;
 typedef struct EphyEmbedSingle		EphyEmbedSingle;
+typedef struct EphyEmbedSingleIface	EphyEmbedSingleIface;
 
-struct EphyEmbedSingleClass
+struct EphyEmbedSingleIface
 {
 	GTypeInterface base_iface;
 
@@ -49,6 +49,7 @@ struct EphyEmbedSingleClass
 	/* Methods */
 
 	void	(* clear_cache)         (EphyEmbedSingle *shell);
+	void	(* clear_auth_cache)	(EphyEmbedSingle *shell);
 	void	(* set_offline_mode)    (EphyEmbedSingle *shell,
 					 gboolean offline);
 	void	(* load_proxy_autoconf) (EphyEmbedSingle *shell,
@@ -61,6 +62,8 @@ GType	ephy_embed_single_get_type		(void);
 
 void	ephy_embed_single_clear_cache		(EphyEmbedSingle *shell);
 
+void	ephy_embed_single_clear_auth_cache	(EphyEmbedSingle *shell);
+
 void	ephy_embed_single_set_offline_mode	(EphyEmbedSingle *shell,
 						 gboolean offline);
 
