@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-embed.h,v 1.28 2004/01/22 23:17:35 chpe Exp $
+ *  $Id: ephy-embed.h,v 1.29 2004/02/20 11:49:42 chpe Exp $
  */
 
 #ifndef EPHY_EMBED_H
@@ -32,13 +32,13 @@ G_BEGIN_DECLS
 
 #define EPHY_TYPE_EMBED			(ephy_embed_get_type ())
 #define EPHY_EMBED(o)			(G_TYPE_CHECK_INSTANCE_CAST ((o), EPHY_TYPE_EMBED, EphyEmbed))
-#define EPHY_EMBED_IFACE(k)		(G_TYPE_CHECK_CLASS_CAST((k), EPHY_TYPE_EMBED, EphyEmbedIFace))
+#define EPHY_EMBED_IFACE(k)		(G_TYPE_CHECK_CLASS_CAST((k), EPHY_TYPE_EMBED, EphyEmbedIface))
 #define EPHY_IS_EMBED(o)		(G_TYPE_CHECK_INSTANCE_TYPE ((o), EPHY_TYPE_EMBED))
 #define EPHY_IS_EMBED_IFACE(k)		(G_TYPE_CHECK_CLASS_TYPE ((k), EPHY_TYPE_EMBED))
-#define EPHY_EMBED_GET_IFACE(inst)	(G_TYPE_INSTANCE_GET_INTERFACE ((inst), EPHY_TYPE_EMBED, EphyEmbedIFace))
+#define EPHY_EMBED_GET_IFACE(inst)	(G_TYPE_INSTANCE_GET_INTERFACE ((inst), EPHY_TYPE_EMBED, EphyEmbedIface))
 
 typedef struct EphyEmbed	EphyEmbed;
-typedef struct EphyEmbedIFace	EphyEmbedIFace;
+typedef struct EphyEmbedIface	EphyEmbedIface;
 
 typedef enum
 {
@@ -135,7 +135,7 @@ typedef enum
 	STATE_IS_SECURE_HIGH
 } EmbedSecurityLevel;
 
-struct EphyEmbedIFace
+struct EphyEmbedIface
 {
 	GTypeInterface base_iface;
 
