@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-history.c,v 1.43 2004/01/12 19:34:47 chpe Exp $
+ *  $Id: ephy-history.c,v 1.45 2004/02/11 14:38:11 marco Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -301,6 +301,7 @@ hosts_removed_cb (EphyNode *node,
 static void
 hosts_changed_cb (EphyNode *node,
 		  EphyNode *child,
+		  guint property_id,
 		  EphyHistory *eb)
 {
 	eb->priv->dirty = TRUE;
@@ -333,6 +334,7 @@ pages_removed_cb (EphyNode *node,
 static void
 pages_changed_cb (EphyNode *node,
 		  EphyNode *child,
+		  guint property_id,
 		  EphyHistory *eb)
 {
 	eb->priv->dirty = TRUE;
@@ -574,6 +576,8 @@ ephy_history_finalize (GObject *object)
 
 	eel_gconf_notification_remove (eb->priv->disable_history_notifier_id);
 
+	g_free (eb->priv->xml_file);
+
 	LOG ("Global history finalized");
 
 	G_OBJECT_CLASS (parent_class)->finalize (object);
