@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: EphyBrowser.cpp,v 1.20 2004/02/12 19:30:48 chpe Exp $
+ *  $Id: EphyBrowser.cpp,v 1.21 2004/02/20 22:44:44 chpe Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -81,7 +81,6 @@
 #include "nsIDocumentCharsetInfo.h"
 #include "nsPromiseFlatString.h"
 #include "nsString.h"
-#include "nsUnicharUtils.h"
 #include "ContentHandler.h"
 
 EphyEventListener::EphyEventListener(void)
@@ -116,10 +115,8 @@ EphyFaviconEventListener::HandleFaviconLink (nsIDOMNode *node)
 	result = linkElement->GetAttribute (attr_rel, value);
 	if (NS_FAILED (result)) return NS_ERROR_FAILURE;
 
-	if (value.Equals(NS_LITERAL_STRING("SHORTCUT ICON"),
-			 nsCaseInsensitiveStringComparator()) ||
-	    value.Equals(NS_LITERAL_STRING("ICON"),
-	    		 nsCaseInsensitiveStringComparator()))
+	if (value.EqualsIgnoreCase("SHORTCUT ICON") ||
+	    value.EqualsIgnoreCase("ICON"))
 	{
 		NS_NAMED_LITERAL_STRING(attr_href, "href");
 		nsAutoString value;
