@@ -17,12 +17,13 @@
  */
 
 #ifdef HAVE_CONFIG_H
-#include <config.h>
+#include "config.h"
 #endif
 
-#include <gtk/gtk.h>
-#include <libgnome/gnome-exec.h>
-#include <libgnome/gnome-i18n.h>
+#if MOZILLA_SNAPSHOT < 12
+
+#include <gtk/gtkmessagedialog.h>
+#include <glib/gi18n.h>
 #include <libgnomevfs/gnome-vfs-utils.h>
 
 #include <nsString.h>
@@ -33,7 +34,6 @@
 #include <nsIWindowWatcher.h>
 #include <nsIServiceManager.h>
 
-#include "ephy-prefs.h"
 #include "eel-gconf-extensions.h"
 
 #include "ExternalProtocolService.h"
@@ -45,13 +45,10 @@ NS_IMPL_ISUPPORTS1(GExternalProtocolService, nsIExternalProtocolService)
 
 GExternalProtocolService::GExternalProtocolService()
 {
-  NS_INIT_ISUPPORTS();
-  /* member initializers and constructor code */
 }
 
 GExternalProtocolService::~GExternalProtocolService()
 {
-  /* destructor code */
 }
 
 /* boolean externalProtocolHandlerExists (in string aProtocolScheme); */
@@ -155,3 +152,5 @@ NS_IMETHODIMP GExternalProtocolService::LoadUrl(nsIURI *aURL)
 
 	return NS_OK;
 }
+
+#endif
