@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: GlobalHistory.cpp,v 1.14 2004/02/12 16:47:42 chpe Exp $
+ *  $Id: GlobalHistory.cpp,v 1.15 2004/02/16 11:56:51 chpe Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -30,13 +30,11 @@
 #include <nsString.h>
 #include <nsIURI.h>
 
-NS_IMPL_ISUPPORTS2(MozGlobalHistory,
 #if MOZILLA_SNAPSHOT > 13
-		   nsIGlobalHistory2,
+NS_IMPL_ISUPPORTS2(MozGlobalHistory, nsIGlobalHistory2, nsIBrowserHistory)
 #else
-		   nsIGlobalHistory,
+NS_IMPL_ISUPPORTS2(MozGlobalHistory, nsIGlobalHistory, nsIBrowserHistory)
 #endif
-		   nsIBrowserHistory)
 
 MozGlobalHistory::MozGlobalHistory ()
 {
