@@ -15,10 +15,11 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: mozilla-embed.cpp,v 1.55 2004/01/04 12:52:05 chpe Exp $
+ *  $Id: mozilla-embed.cpp,v 1.61 2004/02/20 11:49:43 chpe Exp $
  */
 
 #include "mozilla-embed.h"
+#include "mozilla-embed-event.h"
 #include "ephy-embed-shell.h"
 #include "ephy-command-manager.h"
 #include "ephy-string.h"
@@ -29,7 +30,6 @@
 #include "EventContext.h"
 
 #include <gtkmozembed.h>
-#include <gtkmozembed_internal.h>
 #include <nsIWindowWatcher.h>
 #include <nsIURI.h>
 #include <nsIURL.h>
@@ -44,66 +44,33 @@
 static void	mozilla_embed_class_init	(MozillaEmbedClass *klass);
 static void	mozilla_embed_init		(MozillaEmbed *gs);
 static void	mozilla_embed_destroy		(GtkObject *object);
-static void	ephy_embed_iface_init		(EphyEmbedIFace *iface);
+static void	ephy_embed_iface_init		(EphyEmbedIface *iface);
 
-static void 
-mozilla_embed_connect_signals (MozillaEmbed *membed);
-static void
-mozilla_embed_location_changed_cb (GtkMozEmbed *embed, MozillaEmbed *membed);
-static void
-mozilla_embed_title_changed_cb (GtkMozEmbed *embed, MozillaEmbed *membed);
-static void
-mozilla_embed_net_state_all_cb (GtkMozEmbed *embed, const char *aURI,
-                                gint state, guint status, MozillaEmbed *membed);
-static void
-mozilla_embed_progress_cb (GtkMozEmbed *embed, const char *aURI,
-                           gint curprogress, gint maxprogress, MozillaEmbed *membed);
-static void
-mozilla_embed_link_message_cb (GtkMozEmbed *embed, MozillaEmbed *membed);
-static void
-mozilla_embed_js_status_cb (GtkMozEmbed *embed, MozillaEmbed *membed);
-static void
-mozilla_embed_visibility_cb (GtkMozEmbed *embed, gboolean visibility, MozillaEmbed *membed);
-static gint
-mozilla_embed_dom_mouse_click_cb (GtkMozEmbed *embed, gpointer dom_event, MozillaEmbed *membed);
-static gint
-mozilla_embed_dom_mouse_down_cb (GtkMozEmbed *embed, gpointer dom_event, 
-				 MozillaEmbed *membed);
-static void
-mozilla_embed_size_to_cb (GtkMozEmbed *embed, gint width, gint height, MozillaEmbed *membed);
-static void
-mozilla_embed_new_window_cb (GtkMozEmbed *embed, 
-			     GtkMozEmbed **newEmbed,
-                             guint chromemask, MozillaEmbed *membed);
-static void
-mozilla_embed_security_change_cb (GtkMozEmbed *embed, 
-				  gpointer request,
-                                  guint state, MozillaEmbed *membed);
-static EmbedSecurityLevel
-mozilla_embed_security_level (MozillaEmbed *membed);
-static gint
-mozilla_embed_dom_key_down_cb (GtkMozEmbed *embed, gpointer dom_event,
-		               MozillaEmbed *membed);
-
-/* signals to connect on each embed widget */
-static const struct
-{ 
-	char *event; 
-        void *func; /* should be a GtkSignalFunc or similar */
-}
-signal_connections[] =
-{
-	{ "location",        (void *) mozilla_embed_location_changed_cb  },
-        { "net_state_all",   (void *) mozilla_embed_net_state_all_cb     },
-        { "dom_mouse_click", (void *) mozilla_embed_dom_mouse_click_cb   },
-	{ "dom_mouse_down",  (void *) mozilla_embed_dom_mouse_down_cb    },
-        { "new_window",      (void *) mozilla_embed_new_window_cb        },
-        { "security_change", (void *) mozilla_embed_security_change_cb   },
-	{ "dom_key_down",    (void *) mozilla_embed_dom_key_down_cb      },
-
-        /* terminator -- must be last in the list! */
-        { NULL, NULL } 
-};
+static void mozilla_embed_connect_signals	(MozillaEmbed *membed);
+static void mozilla_embed_location_changed_cb	(GtkMozEmbed *embed,
+						 MozillaEmbed *membed);
+static void mozilla_embed_net_state_all_cb	(GtkMozEmbed *embed,
+						 const char *aURI,
+						 gint state,
+						 guint status,
+						 MozillaEmbed *membed);
+static gint mozilla_embed_dom_key_down_cb	(GtkMozEmbed *embed,
+						 gpointer dom_event,
+						 MozillaEmbed *membed);
+static gint mozilla_embed_dom_mouse_click_cb	(GtkMozEmbed *embed,
+						 gpointer dom_event,
+						 MozillaEmbed *membed);
+static gint mozilla_embed_dom_mouse_down_cb	(GtkMozEmbed *embed,
+						 gpointer dom_event, 
+						 MozillaEmbed *membed);
+static void mozilla_embed_new_window_cb		(GtkMozEmbed *embed, 
+						 GtkMozEmbed **newEmbed,
+						 guint chromemask,
+						 MozillaEmbed *membed);
+static void mozilla_embed_security_change_cb	(GtkMozEmbed *embed, 
+						 gpointer request,
+						 guint state, MozillaEmbed *membed);
+static EmbedSecurityLevel mozilla_embed_security_level (MozillaEmbed *membed);
 
 #define MOZILLA_EMBED_GET_PRIVATE(object)(G_TYPE_INSTANCE_GET_PRIVATE ((object), MOZILLA_TYPE_EMBED, MozillaEmbedPrivate))
 
@@ -143,7 +110,7 @@ impl_manager_can_do_command (EphyCommandManager *manager,
 }
 
 static void
-ephy_command_manager_iface_init (EphyCommandManagerIFace *iface)
+ephy_command_manager_iface_init (EphyCommandManagerIface *iface)
 {
 	iface->do_command = impl_manager_do_command;
 	iface->can_do_command = impl_manager_can_do_command;
@@ -296,19 +263,27 @@ _mozilla_embed_get_ephy_browser (MozillaEmbed *embed)
 static void 
 mozilla_embed_connect_signals (MozillaEmbed *embed)
 {
-        gint i;
-	EphyEmbed *gembed;
-
-	gembed = EPHY_EMBED (embed);
-	       
-        /* connect signals */
-        for (i = 0; signal_connections[i].event != NULL; i++)
-        {
-                g_signal_connect (G_OBJECT (embed),
-                                  signal_connections[i].event,
-                                  G_CALLBACK (signal_connections[i].func), 
-                                  embed);
-        }
+	g_signal_connect_object (G_OBJECT (embed), "location",
+				 G_CALLBACK (mozilla_embed_location_changed_cb),
+				 embed, (GConnectFlags) 0);
+	g_signal_connect_object (G_OBJECT (embed), "net_state_all",
+				 G_CALLBACK (mozilla_embed_net_state_all_cb),
+				 embed, (GConnectFlags) 0);
+	g_signal_connect_object (G_OBJECT (embed), "dom_mouse_click",
+				 G_CALLBACK (mozilla_embed_dom_mouse_click_cb),
+				 embed, (GConnectFlags) 0);
+	g_signal_connect_object (G_OBJECT (embed), "dom_mouse_down",
+				 G_CALLBACK (mozilla_embed_dom_mouse_down_cb),
+				 embed, (GConnectFlags) 0);
+	g_signal_connect_object (G_OBJECT (embed), "new_window",
+				 G_CALLBACK (mozilla_embed_new_window_cb),
+				 embed, (GConnectFlags) 0);
+	g_signal_connect_object (G_OBJECT (embed), "security_change",
+				 G_CALLBACK (mozilla_embed_security_change_cb),
+				 embed, (GConnectFlags) 0);
+	g_signal_connect_object (G_OBJECT (embed), "dom_key_down",
+				 G_CALLBACK (mozilla_embed_dom_key_down_cb),
+				 embed, (GConnectFlags) 0);
 }
 
 static void
@@ -316,14 +291,6 @@ mozilla_embed_destroy (GtkObject *object)
 {
 	MozillaEmbed *embed = MOZILLA_EMBED (object);
 	int i;
-	
-	for (i = 0; signal_connections[i].event != NULL; i++)
-        {
-                g_signal_handlers_disconnect_by_func
-			(G_OBJECT (object),
-                         (gpointer)signal_connections[i].func,
-                         (void *)object);
-        }
 
 	if (embed->priv->browser)
 	{
@@ -539,20 +506,11 @@ impl_reload (EphyEmbed *embed,
 	guint32 mflags;
 
 	mflags = GTK_MOZ_EMBED_FLAG_RELOADNORMAL;
-	
-	if ((flags & EMBED_RELOAD_BYPASSCACHE) &&
-	    (flags & EMBED_RELOAD_BYPASSPROXY))
+
+	if (flags & EMBED_RELOAD_FORCE)
 	{
 		mflags = GTK_MOZ_EMBED_FLAG_RELOADBYPASSPROXYANDCACHE;
 	}
-	else if (flags & EMBED_RELOAD_BYPASSCACHE)
-	{
-		mflags = GTK_MOZ_EMBED_FLAG_RELOADBYPASSCACHE;
-	}
-	else if (flags & EMBED_RELOAD_BYPASSPROXY)
-	{
-		mflags = GTK_MOZ_EMBED_FLAG_RELOADBYPASSPROXY;
-	}
 	
 	gtk_moz_embed_reload (GTK_MOZ_EMBED(embed),
 			      mflags);
@@ -859,13 +817,12 @@ mozilla_embed_dom_key_down_cb (GtkMozEmbed *embed, gpointer dom_event,
 	}
 
 	nsCOMPtr<nsIDOMKeyEvent> ev = static_cast<nsIDOMKeyEvent*>(dom_event);
-	if (!ev)
-	{
-		return FALSE;
-	}
+	NS_ENSURE_TRUE (ev, FALSE);
+	nsCOMPtr<nsIDOMEvent> dev = do_QueryInterface (ev);
+	NS_ENSURE_TRUE (dev, FALSE);
 
-	EphyEmbedEvent *info;
-	info = ephy_embed_event_new ();
+	MozillaEmbedEvent *info;
+	info = mozilla_embed_event_new (NS_STATIC_CAST (gpointer, dev));
 
 	gboolean ret = FALSE;
 
@@ -913,7 +870,7 @@ static gint
 mozilla_embed_dom_mouse_click_cb (GtkMozEmbed *embed, gpointer dom_event, 
 				  MozillaEmbed *membed)
 {
-	EphyEmbedEvent *info;
+	MozillaEmbedEvent *info;
 	EventContext event_context;
 	gint return_value = FALSE;
 	nsresult result;
@@ -925,10 +882,15 @@ mozilla_embed_dom_mouse_click_cb (GtkMozEmbed *embed, gpointer dom_event,
 		return FALSE;
 	}
 
-	info = ephy_embed_event_new ();
-	
+	nsCOMPtr<nsIDOMMouseEvent> ev = static_cast<nsIDOMMouseEvent*>(dom_event);
+	NS_ENSURE_TRUE (ev, FALSE);
+	nsCOMPtr<nsIDOMEvent> dev = do_QueryInterface (ev);
+	NS_ENSURE_TRUE (dev, FALSE);
+
+	info = mozilla_embed_event_new (NS_STATIC_CAST (gpointer, dev));
+
 	event_context.Init (mpriv->browser);
-        result = event_context.GetMouseEventInfo (static_cast<nsIDOMMouseEvent*>(dom_event), info);
+        result = event_context.GetMouseEventInfo (ev, MOZILLA_EMBED_EVENT (info));
 
 	if (NS_SUCCEEDED(result))
 	{
@@ -956,7 +918,7 @@ static gint
 mozilla_embed_dom_mouse_down_cb (GtkMozEmbed *embed, gpointer dom_event, 
 				 MozillaEmbed *membed)
 {
-	EphyEmbedEvent *info;
+	MozillaEmbedEvent *info;
 	EventContext event_context;
 	gint return_value = FALSE;
 	nsresult result;
@@ -969,13 +931,18 @@ mozilla_embed_dom_mouse_down_cb (GtkMozEmbed *embed, gpointer dom_event,
 		return FALSE;
 	}
 
-	info = ephy_embed_event_new ();
-	
+	nsCOMPtr<nsIDOMMouseEvent> ev = static_cast<nsIDOMMouseEvent*>(dom_event);
+	NS_ENSURE_TRUE (ev, FALSE);
+	nsCOMPtr<nsIDOMEvent> dev = do_QueryInterface (ev);
+	NS_ENSURE_TRUE (dev, FALSE);
+
+	info = mozilla_embed_event_new (NS_STATIC_CAST (gpointer, dev));
+
 	event_context.Init (mpriv->browser);
-        result = event_context.GetMouseEventInfo (static_cast<nsIDOMMouseEvent*>(dom_event), info);
+        result = event_context.GetMouseEventInfo (ev, MOZILLA_EMBED_EVENT (info));
 	if (NS_FAILED (result)) return FALSE;
 
-	type = ephy_embed_event_get_event_type (info);
+	type = ephy_embed_event_get_event_type ((EphyEmbedEvent *) info);
 		
 	nsCOMPtr<nsIDOMDocument> domDoc;
 	result = event_context.GetTargetDocument (getter_AddRefs(domDoc));
@@ -1061,7 +1028,7 @@ mozilla_embed_security_change_cb (GtkMozEmbed *embed,
 {
 	EmbedSecurityLevel level;
 
-	membed->priv->request = (nsIRequest *) request;
+	membed->priv->request = static_cast<nsIRequest*>(request);
 	membed->priv->security_state = state;
 	level = mozilla_embed_security_level (membed);
 
@@ -1101,7 +1068,7 @@ mozilla_embed_security_level (MozillaEmbed *membed)
 }
 
 static void
-ephy_embed_iface_init (EphyEmbedIFace *iface)
+ephy_embed_iface_init (EphyEmbedIface *iface)
 {
 	iface->load_url = impl_load_url; 
 	iface->stop_load = impl_stop_load;
@@ -1150,7 +1117,7 @@ xul_visibility_cb (GtkWidget *embed, gboolean visibility, GtkWidget *window)
 }
 
 void
-xul_size_to_cb (GtkWidget *embed, gint width, gint height)
+xul_size_to_cb (GtkWidget *embed, gint width, gint height, gpointer dummy)
 {
 	gtk_widget_set_size_request (embed, width, height);
 }
@@ -1165,12 +1132,15 @@ _mozilla_embed_new_xul_dialog (void)
 	gtk_widget_show (embed);
 	gtk_container_add (GTK_CONTAINER (window), embed);
 
-	g_signal_connect_swapped (embed, "destroy_browser",
-				  G_CALLBACK (gtk_widget_destroy), window);
-	g_signal_connect (embed, "visibility",
-			  G_CALLBACK (xul_visibility_cb), window);
-	g_signal_connect (embed, "size_to",
-			  G_CALLBACK (xul_size_to_cb), NULL);
+	g_signal_connect_object (embed, "destroy_browser",
+				 G_CALLBACK (gtk_widget_destroy),
+				 window, G_CONNECT_SWAPPED);
+	g_signal_connect_object (embed, "visibility",
+				 G_CALLBACK (xul_visibility_cb),
+				 window, (GConnectFlags) 0);
+	g_signal_connect_object (embed, "size_to",
+				 G_CALLBACK (xul_size_to_cb),
+				 NULL, (GConnectFlags) 0);
 
 	return GTK_MOZ_EMBED (embed);
 }
