@@ -14,8 +14,14 @@
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *
+ *  $Id: egg-editable-toolbar.c,v 1.46 2004/02/20 22:20:08 chpe Exp $
  */
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
 #include "egg-editable-toolbar.h"
 #include "egg-toolbars-model.h"
 
@@ -513,7 +519,7 @@ popup_toolbar_context_menu_cb (GtkWidget          *toolbar,
 
       position = get_toolbar_position (t, toolbar);
       flags = egg_toolbars_model_get_flags (t->priv->model, position);
-      if (flags && EGG_TB_MODEL_NOT_REMOVABLE)
+      if (flags & EGG_TB_MODEL_NOT_REMOVABLE)
         {
           gtk_widget_set_sensitive (GTK_WIDGET (item), FALSE);
         }
@@ -778,16 +784,20 @@ item_added_cb (EggToolbarsModel   *model,
 	       int                 position,
 	       EggEditableToolbar *t)
 {
+  GtkWidget *dock;
   GtkWidget *toolbar;
   GtkWidget *item;
   GtkAction *action;
 
   toolbar = get_toolbar_nth (t, toolbar_position);
-  gtk_widget_set_size_request (toolbar, -1, -1);
   item = create_item (t, model, toolbar_position, position, &action);
   gtk_toolbar_insert (GTK_TOOLBAR (toolbar),
 		      GTK_TOOL_ITEM (item), position);
 
+  dock = get_dock_nth (t, toolbar_position);
+  gtk_widget_set_size_request (dock, -1, -1);
+  gtk_widget_queue_resize_no_redraw (dock);
+
   /* FIXME Hack to make tooltip work from gtk */
   if (action)
     {
@@ -812,7 +822,6 @@ item_removed_cb (EggToolbarsModel   *model,
 
   if (egg_toolbars_model_n_items (model, toolbar_position) == 0)
     {
-      gtk_widget_set_size_request (toolbar, -1, MIN_TOOLBAR_HEIGHT);
       egg_toolbars_model_remove_toolbar (model, toolbar_position);
     }
 }
@@ -891,7 +900,7 @@ egg_editable_toolbar_construct (EggEditableToolbar *t)
 
       if (n_items == 0)
         {
-            gtk_widget_set_size_request (toolbar, -1, MIN_TOOLBAR_HEIGHT);
+            gtk_widget_set_size_request (dock, -1, MIN_TOOLBAR_HEIGHT);
         }
     }
 
