@@ -14,10 +14,12 @@
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *
+ *  $Id: ephy-gui.c,v 1.14 2004/02/21 19:59:01 chpe Exp $
  */
 
 #ifdef HAVE_CONFIG_H
-#include <config.h>
+#include "config.h"
 #endif
 
 #include "ephy-gui.h"
@@ -47,16 +49,28 @@ ephy_gui_menu_position_under_widget (GtkMenu   *menu,
 	GtkWidget *w = GTK_WIDGET (user_data);
 	gint screen_width, screen_height;
 	GtkRequisition requisition;
+	gboolean rtl;
+
+	rtl = (gtk_widget_get_direction (w) == GTK_TEXT_DIR_RTL);
 
 	gdk_window_get_origin (w->window, x, y);
-	*x += w->allocation.x;
-	*y += w->allocation.y + w->allocation.height;
-
 	gtk_widget_size_request (GTK_WIDGET (menu), &requisition);
 
+	/* FIXME multihead */
 	screen_width = gdk_screen_width ();
 	screen_height = gdk_screen_height ();
 
+	if (rtl)
+	{
+		*x += w->allocation.x + w->allocation.width - requisition.width;
+	}
+	else
+	{
+		*x += w->allocation.x;
+	}
+
+	*y += w->allocation.y + w->allocation.height;
+
 	*x = CLAMP (*x, 0, MAX (0, screen_width - requisition.width));
 	*y = CLAMP (*y, 0, MAX (0, screen_height - requisition.height));
 }
