@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-node-db.c,v 1.9 2003/12/16 17:29:40 marco Exp $
+ *  $Id: ephy-node-db.c,v 1.13 2004/02/12 16:59:26 chpe Exp $
  */
 
 #include "ephy-node-db.h"
@@ -40,7 +40,8 @@ static void ephy_node_db_finalize (GObject *object);
 enum
 {
 	PROP_0,
-	PROP_NAME
+	PROP_NAME,
+	PROP_IMMUTABLE,
 };
 
 #define EPHY_NODE_DB_GET_PRIVATE(object)(G_TYPE_INSTANCE_GET_PRIVATE ((object), EPHY_TYPE_NODE_DB, EphyNodeDbPrivate))
@@ -48,6 +49,7 @@ enum
 struct EphyNodeDbPrivate
 {
 	char *name;
+	gboolean immutable;
 
 	long id_factory;
 
@@ -112,10 +114,12 @@ ephy_node_db_get_property (GObject *object,
 		case PROP_NAME:
 			g_value_set_string (value, db->priv->name);
 			break;
+		case PROP_IMMUTABLE:
+			g_value_set_boolean (value, ephy_node_db_is_immutable (db));
+			break;
 	}
 }
 
-
 static void
 ephy_node_db_set_property (GObject *object,
                            guint prop_id,
@@ -131,6 +135,9 @@ ephy_node_db_set_property (GObject *object,
 		case PROP_NAME:
 			ephy_node_db_set_name (db, g_value_get_string (value));
 			break;
+		case PROP_IMMUTABLE:
+			ephy_node_db_set_immutable (db, g_value_get_boolean (value));
+			break;
 	}
 }
 
@@ -153,6 +160,14 @@ ephy_node_db_class_init (EphyNodeDbClass *klass)
                                                                NULL,
                                                                G_PARAM_READWRITE));
 
+	g_object_class_install_property (object_class,
+                                         PROP_IMMUTABLE,
+                                         g_param_spec_boolean  ("immutable",
+								"Immutable",
+								"Immutable",
+								FALSE,
+								G_PARAM_READWRITE));
+
 	g_type_class_add_private (object_class, sizeof (EphyNodeDbPrivate));
 }
 
@@ -181,7 +196,7 @@ ephy_node_db_finalize (GObject *object)
 		g_hash_table_destroy (ephy_node_databases);
 	}
 
-	g_ptr_array_free (db->priv->id_to_node, FALSE);
+	g_ptr_array_free (db->priv->id_to_node, TRUE);
 
 	g_free (db->priv->name);
 
@@ -229,6 +244,20 @@ ephy_node_db_get_name (EphyNodeDb *db)
 	return db->priv->name;
 }
 
+gboolean
+ephy_node_db_is_immutable (EphyNodeDb *db)
+{
+	return db->priv->immutable;
+}
+
+void
+ephy_node_db_set_immutable (EphyNodeDb *db, gboolean immutable)
+{
+	db->priv->immutable = immutable;
+
+	g_object_notify (G_OBJECT (db), "immutable");
+}
+
 EphyNode *
 ephy_node_db_get_node_from_id (EphyNodeDb *db, long id)
 {
@@ -284,6 +313,7 @@ ephy_node_db_load_from_file (EphyNodeDb *db,
 {
 	xmlTextReaderPtr reader;
 	gboolean success = TRUE;
+	gboolean was_immutable;
 	int ret;
 
 	LOG ("ephy_node_db_load_from_file %s", xml_file)
@@ -301,6 +331,9 @@ ephy_node_db_load_from_file (EphyNodeDb *db,
 		return FALSE;
 	}
 
+	was_immutable = db->priv->immutable;
+	db->priv->immutable = FALSE;
+
 	ret = xmlTextReaderRead (reader);
 	while (ret == 1)
 	{
@@ -349,6 +382,8 @@ ephy_node_db_load_from_file (EphyNodeDb *db,
 
 	xmlFreeTextReader (reader);
 
+	db->priv->immutable = was_immutable;
+
 	STOP_PROFILER ("loading node db")
 
 	return (success && ret == 0);
@@ -378,6 +413,12 @@ ephy_node_db_write_to_xml_valist (EphyNodeDb *db,
 		return -1;
 	}
 
+	ret = xmlTextWriterSetIndent (writer, 1);
+	if (ret < 0) goto out;
+
+	ret = xmlTextWriterSetIndentString (writer, "  ");
+	if (ret < 0) goto out;
+
 	ret = xmlTextWriterStartDocument (writer, "1.0", NULL, NULL);
 	if (ret < 0) goto out;
 
