@@ -1,3 +1,4 @@
+/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
  *  Copyright (C) 2003 Marco Pesenti Gritti
  *
@@ -15,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-bookmarks-import.c,v 1.16 2003/09/03 12:16:19 chpe Exp $
+ *  $Id: ephy-bookmarks-import.c,v 1.20 2004/01/28 19:00:37 chpe Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -28,10 +29,13 @@
 #include <string.h>
 #include <libgnomevfs/gnome-vfs-mime-utils.h>
 
-#include <bonobo/bonobo-i18n.h>
+#include <glib/gi18n.h>
 
 #include "ephy-bookmarks-import.h"
 #include "ephy-debug.h"
+#include "ephy-prefs.h"
+
+#include "eel-gconf-extensions.h"
 
 /**
  * NSItemType: netscape bookmark item type
@@ -59,6 +63,8 @@ bookmark_add (EphyBookmarks *bookmarks,
 
 	bmk = ephy_bookmarks_add (bookmarks, title, address);
 
+	if (bmk == NULL) return NULL;
+
 	if (topic_name)
 	{
 		topic = ephy_bookmarks_find_keyword (bookmarks, topic_name, FALSE);
@@ -67,7 +73,10 @@ bookmark_add (EphyBookmarks *bookmarks,
 			topic = ephy_bookmarks_add_keyword (bookmarks, topic_name);
 		}
 
-		ephy_bookmarks_set_keyword (bookmarks, topic, bmk);
+		if (topic != NULL)
+		{
+			ephy_bookmarks_set_keyword (bookmarks, topic, bmk);
+		}
 	}
 
 	return bmk;
@@ -79,6 +88,8 @@ ephy_bookmarks_import (EphyBookmarks *bookmarks,
 {
 	char *type;
 
+	if (eel_gconf_get_boolean (CONF_LOCKDOWN_DISABLE_BOOKMARK_EDITING)) return FALSE;
+
 	type = gnome_vfs_get_mime_type (filename);
 
 	LOG ("Importing bookmarks of type %s", type)
@@ -371,7 +382,7 @@ xbel_parse_folder (EphyBookmarks *eb, xmlTextReaderPtr reader)
 
 	xmlFree (title);
 
-	g_return_val_if_fail (EPHY_IS_NODE (keyword), list);
+	if (keyword == NULL) return list;
 
 	for (l = list; l != NULL; l = l->next)
 	{
@@ -565,10 +576,16 @@ ephy_bookmarks_import_mozilla (EphyBookmarks *bookmarks,
 			       const char *filename)
 {
 	FILE *bf;  /* bookmark file */
-	GString *name = g_string_new (NULL);
+	GString *name;
 	gchar *parsedname;
 	GString *url = g_string_new (NULL);
-	char *current_folder = NULL;
+	GList *folders = NULL, *l;
+
+	if (eel_gconf_get_boolean (CONF_LOCKDOWN_DISABLE_BOOKMARK_EDITING)) return FALSE;
+
+	name = g_string_new (NULL);
+	url = g_string_new (NULL);
+
 
 	if (!(bf = fopen (filename, "r"))) {
 		g_warning ("Failed to open file: %s\n", filename);
@@ -576,19 +593,49 @@ ephy_bookmarks_import_mozilla (EphyBookmarks *bookmarks,
 	}
 
 	while (!feof (bf)) {
+		EphyNode *node;
 		NSItemType t;
 		t = ns_get_bookmark_item (bf, name, url);
 		switch (t)
 		{
 		case NS_FOLDER:
-			g_free (current_folder);
-			current_folder = g_strdup (name->str);
+			folders = g_list_prepend (folders, g_strdup (name->str));
+			break;
+		case NS_FOLDER_END:
+			if (folders)
+			{
+				/* remove first entry */
+				g_free (folders->data);
+				folders = g_list_delete_link (folders, folders); 
+			}
 			break;
 		case NS_SITE:
 			parsedname = ns_parse_bookmark_item (name);
 
-			bookmark_add (bookmarks, parsedname,
-				      url->str, current_folder);
+			node = bookmark_add (bookmarks, parsedname, url->str, NULL);
+
+			if (node == NULL)
+			{
+				node = ephy_bookmarks_find_bookmark (bookmarks, url->str);
+			}
+
+			for (l = folders; l != NULL; l = l->next)
+			{
+				char *topic = (char *) l->data;
+				EphyNode *keyword;
+
+				keyword = ephy_bookmarks_find_keyword (bookmarks, topic, FALSE);
+			
+				if (keyword == NULL)
+				{
+					keyword = ephy_bookmarks_add_keyword (bookmarks, topic);
+				}
+
+				if (node != NULL && keyword != NULL)
+				{
+					ephy_bookmarks_set_keyword (bookmarks, keyword, node);
+				}
+			}
 			break;
 		default:
 			break;
@@ -608,6 +655,8 @@ ephy_bookmarks_import_xbel (EphyBookmarks *bookmarks,
 	xmlTextReaderPtr reader;
 	GList *list;
 
+	if (eel_gconf_get_boolean (CONF_LOCKDOWN_DISABLE_BOOKMARK_EDITING)) return FALSE;
+
 	if (g_file_test (filename, G_FILE_TEST_EXISTS) == FALSE)
 	{
 		return FALSE;
@@ -728,7 +777,10 @@ parse_rdf_item (EphyBookmarks *bookmarks,
 			topic = ephy_bookmarks_add_keyword (bookmarks, topic_name);
 		}
 
-		ephy_bookmarks_set_keyword (bookmarks, topic, bmk);
+		if (topic != NULL)
+		{
+			ephy_bookmarks_set_keyword (bookmarks, topic, bmk);
+		}
 	}
 
 	xmlFree (title);
@@ -746,11 +798,21 @@ ephy_bookmarks_import_rdf (EphyBookmarks *bookmarks,
 	xmlNodePtr child;
 	xmlNodePtr root;
 
+	if (eel_gconf_get_boolean (CONF_LOCKDOWN_DISABLE_BOOKMARK_EDITING)) return FALSE;
+
 	if (g_file_test (filename, G_FILE_TEST_EXISTS) == FALSE)
 		return FALSE;
 
 	doc = xmlParseFile (filename);
-	g_assert (doc != NULL);
+	if (doc == NULL)
+	{
+		/* FIXME: maybe put up a warning dialogue here, because this
+		 * is a severe dataloss?
+		 */
+		g_warning ("Failed to re-import the bookmarks. All bookmarks lost!\n");
+		return FALSE;
+	}
+
 	root = xmlDocGetRootElement (doc);
 
 	child = root->children;
