@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2002, 2003 Marco Pesenti Gritti
+ *  Copyright (C) 2002-2004 Marco Pesenti Gritti
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-bookmarks.c,v 1.71 2004/01/10 16:35:56 chpe Exp $
+ *  $Id: ephy-bookmarks.c,v 1.76 2004/02/11 20:45:13 chpe Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -42,7 +42,7 @@
 #include <libgnomevfs/gnome-vfs-utils.h>
 
 #define EPHY_BOOKMARKS_XML_ROOT    "ephy_bookmarks"
-#define EPHY_BOOKMARKS_XML_VERSION "1.01"
+#define EPHY_BOOKMARKS_XML_VERSION "1.03"
 #define BOOKMARKS_SAVE_DELAY (3 * 1000)
 #define MAX_FAVORITES_NUM 10
 
@@ -80,7 +80,6 @@ static const EphyBookmarksBookmarkInfo default_bookmarks [] =
 	 * For instance in .nl these should be
 	 * "http://www.google.nl" and "http://www.google.nl/search?q=%s"
 	 */
-
 	{ N_("Search the web"), N_("http://www.google.com/search?q=%s&ie=UTF-8&oe=UTF-8") }
 };
 static int n_default_bookmarks = G_N_ELEMENTS (default_bookmarks);
@@ -111,21 +110,18 @@ enum
 
 static guint ephy_bookmarks_signals[LAST_SIGNAL] = { 0 };
 
-static void
-ephy_bookmarks_class_init (EphyBookmarksClass *klass);
-static void
-ephy_bookmarks_init (EphyBookmarks *tab);
-static void
-ephy_bookmarks_finalize (GObject *object);
+static void ephy_bookmarks_class_init	(EphyBookmarksClass *klass);
+static void ephy_bookmarks_init		(EphyBookmarks *tab);
+static void ephy_bookmarks_finalize	(GObject *object);
 
 static GObjectClass *parent_class = NULL;
 
 GType
 ephy_bookmarks_get_type (void)
 {
-        static GType ephy_bookmarks_type = 0;
+        static GType type = 0;
 
-        if (ephy_bookmarks_type == 0)
+        if (type == 0)
         {
                 static const GTypeInfo our_info =
                 {
@@ -140,12 +136,12 @@ ephy_bookmarks_get_type (void)
                         (GInstanceInitFunc) ephy_bookmarks_init
                 };
 
-                ephy_bookmarks_type = g_type_register_static (G_TYPE_OBJECT,
-							      "EphyBookmarks",
-							      &our_info, 0);
+                type = g_type_register_static (G_TYPE_OBJECT,
+					       "EphyBookmarks",
+					       &our_info, 0);
         }
 
-        return ephy_bookmarks_type;
+        return type;
 }
 
 static void
@@ -444,34 +440,16 @@ ephy_setup_history_notifiers (EphyBookmarks *eb)
 }
 
 static void
-bookmarks_changed_cb (EphyNode *node,
-		      EphyNode *child,
-		      EphyBookmarks *eb)
-{
-	ephy_bookmarks_save_delayed (eb, BOOKMARKS_SAVE_DELAY);
-}
-
-static void
-bookmarks_removed_cb (EphyNode *node,
-		      EphyNode *child,
-		      guint old_index,
-		      EphyBookmarks *eb)
-{
-	g_signal_emit (G_OBJECT (eb), ephy_bookmarks_signals[TREE_CHANGED], 0);
-	ephy_bookmarks_save_delayed (eb, BOOKMARKS_SAVE_DELAY);
-}
-
-static char *
-get_topics_list (EphyBookmarks *eb,
-		 EphyNode *bookmark,
-		 gboolean *no_topics)
+update_bookmark_keywords (EphyBookmarks *eb, EphyNode *bookmark)
 {
+	GValue value = { 0, };
 	GPtrArray *children;
 	int i;
 	GString *list;
+	const char *title;
+	char *normalized_keywords, *case_normalized_keywords;
 
 	list = g_string_new (NULL);
-	*no_topics = TRUE;
 
 	children = ephy_node_get_children (eb->priv->keywords);
 	for (i = 0; i < children->len; i++)
@@ -489,25 +467,77 @@ get_topics_list (EphyBookmarks *eb,
 			topic = ephy_node_get_property_string
 				(kid, EPHY_NODE_KEYWORD_PROP_NAME);
 			g_string_append (list, topic);
-			*no_topics = FALSE;
+			g_string_append (list, " ");
 		}
 	}
 
-	return g_string_free (list, FALSE);
-}
+	title = ephy_node_get_property_string
+		(bookmark, EPHY_NODE_BMK_PROP_TITLE);
+	g_string_append (list, " ");
+	g_string_append (list, title);
 
-static void
-update_topics_list (EphyNode *bookmark, const char *list)
-{
-	GValue value = { 0, };
+	normalized_keywords = g_utf8_normalize (list->str, -1, G_NORMALIZE_ALL);
+	case_normalized_keywords = g_utf8_casefold (normalized_keywords, -1);
 
 	g_value_init (&value, G_TYPE_STRING);
-	g_value_set_string (&value, list);
+	g_value_set_string (&value, case_normalized_keywords);
 	ephy_node_set_property (bookmark, EPHY_NODE_BMK_PROP_KEYWORDS,
 			        &value);
 	g_value_unset (&value);
+
+	g_string_free (list, TRUE);
+	g_free (normalized_keywords);
+	g_free (case_normalized_keywords);
 }
 
+static void
+bookmarks_changed_cb (EphyNode *node,
+		      EphyNode *child,
+		      guint property_id,
+		      EphyBookmarks *eb)
+{
+	if (property_id == EPHY_NODE_BMK_PROP_TITLE)
+	{
+		update_bookmark_keywords (eb, child);
+	}
+
+	ephy_bookmarks_save_delayed (eb, BOOKMARKS_SAVE_DELAY);
+}
+
+static void
+bookmarks_removed_cb (EphyNode *node,
+		      EphyNode *child,
+		      guint old_index,
+		      EphyBookmarks *eb)
+{
+	g_signal_emit (G_OBJECT (eb), ephy_bookmarks_signals[TREE_CHANGED], 0);
+	ephy_bookmarks_save_delayed (eb, BOOKMARKS_SAVE_DELAY);
+}
+
+static gboolean
+bookmark_is_categorized (EphyBookmarks *eb, EphyNode *bookmark)
+{
+	GPtrArray *children;
+	int i;
+
+	children = ephy_node_get_children (eb->priv->keywords);
+	for (i = 0; i < children->len; i++)
+	{
+		EphyNode *kid;
+
+		kid = g_ptr_array_index (children, i);
+
+		if (kid != eb->priv->notcategorized && 
+		    kid != eb->priv->favorites &&
+		    kid != eb->priv->bookmarks &&
+		    ephy_node_has_child (kid, bookmark))
+		{
+			return TRUE;
+		}
+	}
+
+	return FALSE;
+}
 
 static void
 topics_removed_cb (EphyNode *node,
@@ -522,22 +552,17 @@ topics_removed_cb (EphyNode *node,
 	for (i = 0; i < children->len; i++)
 	{
 		EphyNode *kid;
-		gboolean no_topics;
-		char *list;
 
 		kid = g_ptr_array_index (children, i);
-		list = get_topics_list (eb, kid, &no_topics);
 
-		if (no_topics &&
+		if (bookmark_is_categorized (eb, kid) &&
 		    !ephy_node_has_child (eb->priv->notcategorized, kid))
 		{
 			ephy_node_add_child
 				(eb->priv->notcategorized, kid);
 		}
 
-		update_topics_list (kid, list);
-
-		g_free (list);
+		update_bookmark_keywords (eb, kid);
 	}
 
 	g_signal_emit (G_OBJECT (eb), ephy_bookmarks_signals[TREE_CHANGED], 0);
@@ -771,6 +796,7 @@ ephy_bookmarks_add (EphyBookmarks *eb,
 	g_value_unset (&value);
 
 	update_has_smart_address (eb, bm, url);
+	update_bookmark_keywords (eb, bm);
 
 	ephy_node_add_child (eb->priv->bookmarks, bm);
 	ephy_node_add_child (eb->priv->notcategorized, bm);
@@ -898,6 +924,17 @@ options_find_next_option (const char *current)
 	return (char *) ret;
 }
 
+static char *
+options_find_first_option (const char *input)
+{
+	const char *start;
+
+	if (!input) return NULL;
+	start = strrchr (input, '{');
+	if (!start || !(*start)) return NULL;
+	return options_skip_spaces (start+1);
+}
+
 /**
  * Very simple parser for option strings in the
  * form a=b,c=d,e="f g",...
@@ -907,7 +944,7 @@ smart_url_options_get (const gchar *options, const gchar *option)
 {
 	gchar *ret = NULL;
 	gsize optionlen = strlen (option);
-	const gchar *current = options_skip_spaces (options);
+	const gchar *current = options_find_first_option (options_skip_spaces (options));
 
 	while (current)
 	{
@@ -983,6 +1020,7 @@ ephy_bookmarks_solve_smart_url (EphyBookmarks *eb,
 
 	arg = g_convert (content, strlen (content),
 			 encoding, "UTF-8", NULL, NULL, NULL);
+	if (arg == NULL) return NULL;
 	escaped_arg = gnome_vfs_escape_string (arg);
 
 	t1 = smarturl_only;
@@ -1138,15 +1176,10 @@ ephy_bookmarks_set_keyword (EphyBookmarks *eb,
 			    EphyNode *keyword,
 			    EphyNode *bookmark)
 {
-	gboolean no_topics;
-	char *list;
-
 	if (ephy_node_has_child (keyword, bookmark)) return;
 
 	ephy_node_add_child (keyword, bookmark);
 
-	list = get_topics_list (eb, bookmark, &no_topics);
-
 	if (ephy_node_has_child (eb->priv->notcategorized, bookmark))
 	{
 		LOG ("Remove from categorized bookmarks")
@@ -1154,8 +1187,7 @@ ephy_bookmarks_set_keyword (EphyBookmarks *eb,
 			(eb->priv->notcategorized, bookmark);
 	}
 
-	update_topics_list (bookmark, list);
-	g_free (list);
+	update_bookmark_keywords (eb, bookmark);
 
 	g_signal_emit (G_OBJECT (eb), ephy_bookmarks_signals[TREE_CHANGED], 0);
 }
@@ -1165,16 +1197,11 @@ ephy_bookmarks_unset_keyword (EphyBookmarks *eb,
 			      EphyNode *keyword,
 			      EphyNode *bookmark)
 {
-	gboolean no_topics;
-	char *list;
-
 	if (!ephy_node_has_child (keyword, bookmark)) return;
 
 	ephy_node_remove_child (keyword, bookmark);
 
-	list = get_topics_list (eb, bookmark, &no_topics);
-
-	if (no_topics &&
+	if (!bookmark_is_categorized (eb, bookmark) &&
 	    !ephy_node_has_child (eb->priv->notcategorized, bookmark))
 	{
 		LOG ("Add to not categorized bookmarks")
@@ -1182,8 +1209,7 @@ ephy_bookmarks_unset_keyword (EphyBookmarks *eb,
 			(eb->priv->notcategorized, bookmark);
 	}
 
-	update_topics_list (bookmark, list);
-	g_free (list);
+	update_bookmark_keywords (eb, bookmark);
 
 	g_signal_emit (G_OBJECT (eb), ephy_bookmarks_signals[TREE_CHANGED], 0);
 }
