@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-completion-model.c,v 1.11 2004/02/11 14:38:28 marco Exp $
+ *  $Id: ephy-completion-model.c,v 1.12 2004/02/20 22:37:42 marco Exp $
  */
 
 #include <config.h>
@@ -358,13 +358,16 @@ is_base_address (const char *address)
 	{
 		if (*address == '/') slashes++;
 
-		/* Base uris has 3 slashes like http://www.gnome.org/ */
-		if (slashes == 4) return FALSE;
-
 		address++;
+
+		/* Base uris has 3 slashes like http://www.gnome.org/ */
+		if (slashes == 3)
+		{
+			return (*address == '\0');
+		}
 	}
 
-	return TRUE;
+	return FALSE;
 }
 
 static void
@@ -389,7 +392,7 @@ init_relevance_col (GValue *value, EphyNode *node, int group)
 		address = ephy_node_get_property_string
 			(node, EPHY_NODE_PAGE_PROP_LOCATION);
 
-		visits = MAX (visits, (1 << 5) - 1);
+		visits = MIN (visits, (1 << 5) - 1);
 
 		if (is_base_address (address))
 		{
