@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-toolbars-model.c,v 1.21 2003/12/27 10:32:42 chpe Exp $
+ *  $Id: ephy-toolbars-model.c,v 1.23 2004/01/09 20:49:07 clahey Exp $
  */
 
 #include "ephy-toolbars-model.h"
@@ -23,6 +23,8 @@
 #include "ephy-bookmarks.h"
 #include "ephy-node-common.h"
 #include "ephy-file-helpers.h"
+#include "ephy-history.h"
+#include "ephy-embed-shell.h"
 #include "ephy-shell.h"
 #include "ephy-debug.h"
 #include "ephy-string.h"
@@ -200,20 +202,22 @@ impl_get_item_id (EggToolbarsModel *t,
 			}
 
 			node = ephy_bookmarks_add (bookmarks, title, netscape_url[URL]);
-			g_return_val_if_fail (node != NULL, NULL);
 
-			gh = ephy_embed_shell_get_global_history (EPHY_EMBED_SHELL (ephy_shell));
-			icon = ephy_history_get_icon (gh, netscape_url[URL]);
-
-			if (icon)
+			if (node != NULL)
 			{
-				ephy_bookmarks_set_icon (bookmarks, netscape_url[URL], icon);
+				gh = EPHY_HISTORY (ephy_embed_shell_get_global_history (embed_shell));
+				icon = ephy_history_get_icon (gh, netscape_url[URL]);
+
+				if (icon)
+				{
+					ephy_bookmarks_set_icon (bookmarks, netscape_url[URL], icon);
+				}
 			}
 		}
 
 		g_strfreev (netscape_url);
 
-		g_return_val_if_fail (node != NULL, NULL);
+		if (node == NULL) return NULL;
 
 		return ephy_toolbars_model_get_action_name
 			(model, ephy_node_get_id (node));
