@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-window.c,v 1.165 2004/01/21 23:39:43 marco Exp $
+ *  $Id: ephy-window.c,v 1.168 2004/02/13 14:13:02 chpe Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -39,7 +39,7 @@
 #include "ephy-zoom.h"
 #include "ephy-debug.h"
 #include "ephy-file-helpers.h"
-#include "statusbar.h"
+#include "ephy-statusbar.h"
 #include "toolbar.h"
 #include "popup-commands.h"
 #include "ephy-encoding-menu.h"
@@ -78,6 +78,7 @@ static GtkActionEntry ephy_menu_entries [] = {
 	{ "View", NULL, N_("_View") },
 	{ "Bookmarks", NULL, N_("_Bookmarks") },
 	{ "Go", NULL, N_("_Go") },
+	{ "Tools", NULL, N_("T_ools") },
 	{ "Tabs", NULL, N_("_Tabs") },
 	{ "Help", NULL, N_("_Help") },
 	{ "PopupAction", NULL, "" },
@@ -271,7 +272,7 @@ static GtkActionEntry ephy_popups_entries [] = {
 	  NULL, G_CALLBACK (popup_cmd_link_in_new_window) },
 	{ "OpenLinkInNewTab", NULL, N_("Open Link in New _Tab"),
 	  NULL, NULL, G_CALLBACK (popup_cmd_link_in_new_tab) },
-	{ "DownloadLink", NULL, N_("_Download Link"), NULL,
+	{ "DownloadLink", EPHY_STOCK_DOWNLOAD, N_("_Download Link"), NULL,
 	  NULL, G_CALLBACK (popup_cmd_download_link) },
 	{ "DownloadLinkAs", GTK_STOCK_SAVE_AS, N_("_Save Link As..."), NULL,
 	  NULL, G_CALLBACK (popup_cmd_download_link_as) },
@@ -408,21 +409,6 @@ ephy_window_destroy (GtkObject *gtkobject)
         GTK_OBJECT_CLASS (parent_class)->destroy (gtkobject);
 }
 
-static void
-ephy_window_selection_received_cb (GtkWidget *widget,
-				   GtkSelectionData *selection_data,
-				   guint time, EphyWindow *window)
-{
-	EphyTab *tab;
-
-	if (selection_data->length <= 0 || selection_data->data == NULL)
-		return;
-
-	tab = ephy_window_get_active_tab (window);
-
-	ephy_embed_load_url (ephy_tab_get_embed (tab), selection_data->data);
-}
-
 static void
 add_widget (GtkUIManager *merge, GtkWidget *widget, EphyWindow *window)
 {
@@ -1048,8 +1034,8 @@ sync_tab_load_progress (EphyTab *tab, GParamSpec *pspec, EphyWindow *window)
 {
 	if (window->priv->closing) return;
 
-	statusbar_set_progress (EPHY_STATUSBAR (window->priv->statusbar),
-				ephy_tab_get_load_percent (tab));
+	ephy_statusbar_set_progress (EPHY_STATUSBAR (window->priv->statusbar),
+				     ephy_tab_get_load_percent (tab));
 }
 
 static void
@@ -1180,8 +1166,8 @@ sync_tab_security (EphyTab *tab, GParamSpec *pspec, EphyWindow *window)
 
 	}
 
-	statusbar_set_security_state (EPHY_STATUSBAR (window->priv->statusbar),
-			              secure, tooltip);
+	ephy_statusbar_set_security_state (EPHY_STATUSBAR (window->priv->statusbar),
+					   secure, tooltip);
 	g_free (tooltip);
 
 }
@@ -1922,18 +1908,12 @@ ephy_window_init (EphyWindow *window)
 	/* Setup the UI manager and connect verbs */
 	setup_ui_manager (window);
 
-	window->priv->toolbar = toolbar_new (window);
-	gtk_box_pack_end (GTK_BOX (window->priv->menu_dock),
-			  GTK_WIDGET (window->priv->toolbar),
-			  FALSE, FALSE, 0);
-
-
 	window->priv->notebook = setup_notebook (window);
 	gtk_box_pack_start (GTK_BOX (window->priv->main_vbox),
 			    GTK_WIDGET (window->priv->notebook),
 			    TRUE, TRUE, 0);
 
-	window->priv->statusbar = statusbar_new ();
+	window->priv->statusbar = ephy_statusbar_new ();
 	gtk_box_pack_start (GTK_BOX (window->priv->main_vbox),
 			    GTK_WIDGET (window->priv->statusbar),
 			    FALSE, TRUE, 0);
@@ -1949,6 +1929,12 @@ ephy_window_init (EphyWindow *window)
 	window->priv->enc_menu = ephy_encoding_menu_new (window);
 	window->priv->bmk_menu = ephy_bookmarks_menu_new (window);
 
+	/* create the toolbar */
+	window->priv->toolbar = toolbar_new (window);
+	gtk_box_pack_end (GTK_BOX (window->priv->menu_dock),
+			  GTK_WIDGET (window->priv->toolbar),
+			  FALSE, FALSE, 0);
+
 	/* Once the window is sufficiently created let the extensions attach to it */
 	manager = EPHY_EXTENSION (ephy_shell_get_extensions_manager (ephy_shell));
 	ephy_extension_attach_window (manager, window);
@@ -1958,10 +1944,6 @@ ephy_window_init (EphyWindow *window)
 	gtk_widget_show (GTK_WIDGET (window->priv->notebook));
 	gtk_widget_show (window->priv->statusbar);
 
-	g_signal_connect (window,
-			  "selection-received",
-			  G_CALLBACK (ephy_window_selection_received_cb),
-			  window);
 	g_signal_connect (window, "window-state-event",
 			  G_CALLBACK (ephy_window_state_event_cb),
 			  window);
