@@ -1,6 +1,6 @@
 /*
  *  Copyright (C) 200-2003 Marco Pesenti Gritti
- *  Copyright (C) 2003 Christian Persch
+ *  Copyright (C) 2003, 2004 Christian Persch
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: prefs-dialog.c,v 1.64 2004/01/06 14:36:23 chpe Exp $
+ *  $Id: prefs-dialog.c,v 1.75 2004/02/12 20:08:24 chpe Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -39,6 +39,7 @@
 #include "ephy-debug.h"
 #include "ephy-ellipsizing-label.h"
 #include "ephy-file-chooser.h"
+#include "ephy-file-helpers.h"
 #include "ephy-tree-model-node.h"
 #include "ephy-tree-model-sort.h"
 
@@ -255,7 +256,7 @@ EphyDialogProperty properties [] =
 	{ "homepage_entry",			CONF_GENERAL_HOMEPAGE,	  PT_AUTOAPPLY,	G_TYPE_STRING },
 	{ "homepage_current_button",		NULL,			  PT_NORMAL,	0 },
 	{ "homepage_blank_button",		NULL,			  PT_NORMAL,	0 },
-	{ "auto_open_downloads_checkbutton",	CONF_AUTO_OPEN_DOWNLOADS, PT_AUTOAPPLY,	0 },
+	{ "automatic_downloads_checkbutton",	CONF_AUTO_DOWNLOADS,      PT_AUTOAPPLY,	0 },
 	{ "download_path_button",		NULL,			  PT_NORMAL,	0 },
 
 	/* Fonts and Colors */
@@ -792,10 +793,15 @@ setup_add_language_dialog (PrefsDialog *pd)
 
 	dialog =  EPHY_DIALOG (g_object_new (EPHY_TYPE_DIALOG,
 					     "parent-window", window,
+					     "default-width", 260,
+					     "default-height", 230,
 					     NULL));
 
-	ephy_dialog_construct (dialog,  add_lang_props,
-			       "prefs-dialog.glade", "add_language_dialog");
+	ephy_dialog_construct (dialog, 
+			       add_lang_props,
+			       ephy_file ("prefs-dialog.glade"),
+			       "add_language_dialog",
+			       NULL);
 
 	store = gtk_list_store_new (2, G_TYPE_STRING, G_TYPE_STRING);
 
@@ -1080,36 +1086,39 @@ create_language_section (EphyDialog *dialog)
 static char*
 get_download_button_label ()
 {
-	char *label, *key, *desktop_path, *home_path, *tmp;
+	char *key, *label, *downloads_path, *converted_dp;
 
 	key = eel_gconf_get_string (CONF_STATE_DOWNLOAD_DIR);
 
-	tmp = g_build_filename (g_get_home_dir (), "Desktop", NULL);
-	desktop_path = g_filename_to_utf8 (tmp, -1, NULL, NULL, NULL);
-	home_path = g_filename_to_utf8 (g_get_home_dir (), -1, NULL, NULL, NULL);
-	g_free (tmp);
+	downloads_path = ephy_file_downloads_dir ();
+	converted_dp = g_filename_to_utf8 (downloads_path, -1, NULL, NULL, NULL);
 
-	if (g_utf8_collate (key, desktop_path) == 0)
+	if (key == NULL || g_utf8_collate (key, "~") == 0)
 	{
-		g_free (key);
-		label = g_strdup (_("Desktop")); 
-	}
-	else if (g_utf8_collate (key, home_path) == 0)
-	{
-		g_free (key);
 		/* Note that this does NOT refer to the home page but to a
 		 * user's home folder. It should be translated by the same
 		 * term as GTK+'s "Home" string to be consistent with the
 		 * filechooser */
 		label = g_strdup (_("Home"));
 	}
+	else if ((converted_dp != NULL && g_utf8_collate (key, converted_dp) == 0) ||
+		 g_utf8_collate (key, "Downloads") == 0)
+	{
+		label = g_strdup (_("Downloads"));
+	}
+	else if (g_utf8_collate (key, "~/Desktop") == 0)
+	{
+		label = g_strdup (_("Desktop")); 
+	}
 	else
 	{
-		label = key;
+		label = g_strdup (key);
 	}
 
-	g_free (desktop_path);
-	g_free (home_path);
+	g_free (downloads_path);
+	g_free (converted_dp);
+	g_free (key);
+
 	return label;
 }
 	
@@ -1146,8 +1155,9 @@ prefs_dialog_init (PrefsDialog *pd)
 
 	ephy_dialog_construct (dialog,
 			       properties,
-			       "prefs-dialog.glade",
-			       "prefs_dialog");
+			       ephy_file ("prefs-dialog.glade"),
+			       "prefs_dialog",
+			       NULL);
 
 	ephy_dialog_add_enum (dialog, properties[ACCEPT_COOKIES_PROP].id,
 			      n_cookies_accept_enum, cookies_accept_enum);
@@ -1276,21 +1286,19 @@ download_path_response_cb (GtkDialog *fc, gint response, EphyDialog *dialog)
 	{
 		char *dir;
 
-		dir = gtk_file_chooser_get_current_folder (GTK_FILE_CHOOSER (fc));
+		dir = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (fc));
 		if (dir != NULL)
 		{
 			GtkWidget *button;
-			char *label, *converted;
+			char *label;
+
+			eel_gconf_set_path (CONF_STATE_DOWNLOAD_DIR, dir);
 
-			converted = g_filename_to_utf8 (dir, -1, NULL, NULL, NULL);
-			eel_gconf_set_string (CONF_STATE_DOWNLOAD_DIR, converted);
-			
 			button = ephy_dialog_get_control (dialog, properties[DOWNLOAD_PATH_BUTTON_PROP].id);
 			label = get_download_button_label ();
 			ephy_ellipsizing_label_set_text ((EphyEllipsizingLabel*) GTK_BIN (button)->child,
 							  label);
 
-			g_free (converted);
 			g_free (dir);
 			g_free (label);
 		}
